@@ -185,6 +185,16 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 	for (node = xmlDocGetRootElement (doc)->children; node; node = node->next) {
 		d(g_print ("\t%s\n", node->name));
 		if (!strcmp (node->name, "product")) {
+
+			tmp = xmlGetProp (node, "disallownew");
+			if (tmp && !strcmp(tmp, "1")) {
+				xmlFree (tmp);
+				continue;
+			}
+			if (tmp) {
+				xmlFree(tmp);
+			}
+
 			prod = g_new0 (BugzillaProduct, 1);
 			prod->bts = bts;
 
@@ -206,7 +216,6 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 						continue;
 					} 
 					xmlFree (tmp);
-
 					comp = g_new0 (BugzillaComponent, 1);
 					comp->product = prod;
 					
@@ -526,8 +535,13 @@ load_bugzilla (const char *filename)
 	bts->severity_node   = gnome_config_get_string ("severity_node=severities");
 	bts->severity_item   = gnome_config_get_string ("severity_item=severity");
 	bts->severity_header = gnome_config_get_string ("severity_header=Severity");
-	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME )
-		bugzilla_get_md5sums (bts, gnome_config_get_string ("md5sums"));
+	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME ) {
+		s = gnome_config_get_string ("md5sums");
+		if (s && s!=NULL) {
+			bugzilla_get_md5sums (bts, s);
+			g_free (s);
+		}
+	}
 	
 	bts->products_xml = get_xml_file (bts, "products", 
 					  bts->products_xml_md5,
@@ -1100,6 +1114,11 @@ load_applets (GnomeIconTheme *git)
 
 	for (i = 0; i < info_list->_length; i++) {
 		info = info_list->_buffer + i;
+		if (!bonobo_server_info_prop_lookup (info,
+						     BA_BUGZILLA_BUGZILLA,
+NULL)) {
+			continue;
+		}
 
 		bugzilla_application_new (
 			bonobo_server_info_prop_lookup (info, "name", langs),
@@ -1151,7 +1170,7 @@ visit_cb (const char *rel_path,
 		goto visit_cb_out;
 	}
     
-	if (gnome_desktop_item_get_entry_type (ditem) != GNOME_DESKTOP_ITEM_TYPE_APPLICATION)
+	if ((gnome_desktop_item_get_entry_type (ditem) != GNOME_DESKTOP_ITEM_TYPE_APPLICATION) || !gnome_desktop_item_get_string (ditem, BUGZILLA_BUGZILLA))
 		goto visit_cb_out;
 
 	icon = gnome_desktop_item_get_icon (ditem, git);
@@ -1471,10 +1490,6 @@ generate_email_text (gboolean include_headers)
 	GString *email;
 	char *subject, *body, *s, *debug_info, *version, *severity;
 
-	gboolean is_bugzilla;
-       
-	is_bugzilla = !(GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active || druid_data.product == NULL);
-
 	email = g_string_new (NULL);
 
 	subject    = buddy_get_text ("desc-subject");
@@ -1496,11 +1511,7 @@ generate_email_text (gboolean include_headers)
 	get_distro_name();
 	if (druid_data.distro)
 		g_string_append_printf (email, "Distribution: %s\n", druid_data.distro);
-	if (!is_bugzilla) {
-		g_string_append (email, "(This bug report was generated by Bug Buddy " VERSION ")\n");
-		g_string_append (email, "Description:\n");
-		
-	} else if (druid_data.product->bts->submit_type == BUGZILLA_SUBMIT_DEBIAN) {
+	if (druid_data.product->bts->submit_type == BUGZILLA_SUBMIT_DEBIAN) {
 		/* This is what gnome.org and ximian.com use */
 		g_string_append_printf (email, "Package: %s\n", druid_data.product->name);
 		g_string_append_printf (email, "%s: %s\n", druid_data.product->bts->severity_header, severity);					
