@@ -126,6 +126,38 @@ mail_lock_text (void)
 	}
 }
 
+static gboolean
+check_old_version (void)
+{
+
+	GDateDay   day;
+	GDateMonth month;
+	GDateYear  year;
+	GDate *gnome_date, *current_date;
+
+	if (druid_data.gnome_date) {
+		year = atoi (strtok (druid_data.gnome_date, "-"));
+		month = atoi (strtok (NULL, "-"));
+		day = atoi (strtok (NULL, "-"));
+	} else {
+		return FALSE;
+	}
+
+	gnome_date = g_date_new_dmy (day, month, year);
+	current_date = g_date_new ();
+	g_date_set_time (current_date, time (NULL));
+	g_date_add_months (gnome_date, 6);
+
+	if (g_date_compare (gnome_date, current_date) < 0) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+
+
+
 void
 druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel)
 {
@@ -158,12 +190,21 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 		NULL
 	};
 
+	static const char *translators;
+
+	/* Translators should localize the following string
+         * which will give them credit in the About box.
+         * E.g. "Fulano de Tal <fulano@detal.com>"
+         */
+        translators = _("translator_credits-PLEASE_ADD_YOURSELF_HERE");
+
 	if (about) {
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 		
-	pixbuf = gdk_pixbuf_new_from_file(BUDDY_ICONDIR "/bug-buddy.png", NULL);
+	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+					   "bug-buddy", 48, 0, NULL);
 	
 	about = gnome_about_new (_("Bug Buddy"), VERSION,
 				 "Copyright \xc2\xa9 1999-2002 Jacob Berkman\n"
@@ -172,7 +213,8 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 				 _("The graphical bug reporting tool for GNOME."),
 				 authors,
 				 documentors,
-				 NULL, pixbuf);
+				 (strcmp (translators, "translator_credits-PLEASE_ADD_YOURSELF_HERE")
+					 ? translators : NULL), pixbuf);
 
 	if (pixbuf != NULL)
 		gdk_pixbuf_unref (pixbuf);
@@ -246,8 +288,22 @@ druid_set_state (BuddyState state)
 		if (druid_data.bug_type==BUG_DEBUG) {
 			GtkWidget *nb;
 			nb = GET_WIDGET ("gdb-notebook");
+
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (nb), 1);
 			gtk_widget_hide (GET_WIDGET ("debugging-options-button"));
+		} else if (check_old_version() == TRUE) {
+			GtkLabel *label;
+			const gchar *str;
+			gchar *newstr;
+
+			label = GTK_LABEL (GET_WIDGET ("gdb-label"));
+			str = gtk_label_get_text (label);
+			newstr = g_strdup_printf (_("%s\n\nNotice that the software you are running (%s) is older than six months.\nYou may want to consider upgrading to a newer version of %s system"), 
+					     str, 
+					     druid_data.gnome_platform_version,
+					     druid_data.gnome_distributor);
+			gtk_label_set_text (label, newstr);
+			g_free (newstr);
 		}
 		break;
 	case STATE_PRODUCT:
@@ -260,7 +316,9 @@ druid_set_state (BuddyState state)
 		/* nothing to do */
 		break;		
 	case STATE_DESC:
-		mail_write_template();
+		if (druid_data.description_filled == FALSE) {
+			mail_write_template();
+		}
 		break;
 	case STATE_EMAIL_CONFIG:
 		/* FIXME: change next icon */
@@ -299,8 +357,7 @@ on_druid_prev_clicked (GtkWidget *w, gpointer data)
 			newstate = STATE_MOSTFREQ;
 			break;
 		}
-		if (!druid_data.component_skipped && 
-		    !GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
+		if (!druid_data.component_skipped) {
 			newstate = STATE_COMPONENT;
 			break;
 		}
@@ -959,30 +1016,6 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		BugzillaProduct *product = NULL;
 		BugzillaApplication *application = NULL;
 		/* check that the package is ok */
-		if (GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
-			static gboolean dialog_shown = FALSE;
-			if (!dialog_shown) {
-				d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-							    0,
-							    GTK_MESSAGE_WARNING,
-							    GTK_BUTTONS_OK,
-							    _("Since Bug Buddy doesn't know about the product "
-							      "you wish to submit a bug report in, you will have "
-							      "to manually address the bug report."));
-				gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
-				gtk_dialog_run (GTK_DIALOG (d));
-				gtk_widget_destroy (d);
-				dialog_shown = TRUE;
-			}
-			buddy_set_text ("email-to-entry", "");
-			druid_data.product = NULL;
-			druid_data.component = NULL;
-			newstate = STATE_DESC;
-			druid_data.component_skipped = TRUE;
-			druid_data.mostfreq_skipped = TRUE;
-			break;
-		}
- 
 		if (druid_data.show_products) {
 			product = get_selected_row ("product-list", PRODUCT_DATA);
  			if (!product) {
@@ -996,7 +1029,14 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				gtk_dialog_run (GTK_DIALOG (d));
 				gtk_widget_destroy (d);
 				return;
+			} else {
+				gchar *text;
+				text = g_strdup_printf (_("Please choose a component, version, and severity level for product %s"), product->name);
+				
+				buddy_set_text ("component-label", text);
+				g_free (text);
 			}
+				
 		} else {
 			application = get_selected_row ("product-list", PRODUCT_DATA);
  			if (!application) {
@@ -1010,7 +1050,14 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				gtk_dialog_run (GTK_DIALOG (d));
 				gtk_widget_destroy (d);
 				return;
+			} else {
+				gchar *text;
+				text = g_strdup_printf (_("Please choose a component, version, and severity level for application %s"), application->name);
+
+				buddy_set_text ("component-label", text);
+				g_free (text);
 			}
+
 			if (application->bugzilla && application->product) {
 				BugzillaBTS *bts = g_hash_table_lookup (druid_data.bugzillas, application->bugzilla);
 				if (bts) {
@@ -1018,28 +1065,16 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				}
 			}
 			if (!product) {
-				if (!application->email) {
-					d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-								    0,
-								    GTK_MESSAGE_WARNING,
-								    GTK_BUTTONS_OK,
-								    _("This application has not included information about "
-								      "how to submit bugs.\n\n"
-								      "If you know an email address where bug reports should be sent, "
-								      "you will be able to specify that later.\n\n"
-								      "You may be able to find one in an \"About\" box in the "
-								      "application, or in the application's documentation."));
-					gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
-					gtk_dialog_run (GTK_DIALOG (d));
-					gtk_widget_destroy (d);
-				}
-				buddy_set_text ("email-to-entry", application->email);
-				druid_data.product = NULL;
-				druid_data.component = NULL;
-				newstate = STATE_DESC;
-				druid_data.component_skipped = TRUE;
-				druid_data.mostfreq_skipped = TRUE;
-				break;
+				d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
+							    0,
+							    GTK_MESSAGE_ERROR,
+							    GTK_BUTTONS_OK,
+							    _("This Application has bug information, but Bug Buddy doesn't know about it. Please choose another application."));
+				gtk_dialog_set_default_response (GTK_DIALOG (d),
+								 GTK_RESPONSE_OK);
+				gtk_dialog_run (GTK_DIALOG (d));
+				gtk_widget_destroy (d);
+				return;
 			}
 				
 		}
@@ -1097,6 +1132,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		/* validate subject, description, and file name */
 		if (!desc_page_ok ())
 			return;
+		druid_data.description_filled = TRUE;
 		break;
 	case STATE_EMAIL_CONFIG:
 		if (!mail_config_page_ok ())
@@ -1136,6 +1172,5 @@ on_druid_cancel_clicked (GtkWidget *w, gpointer data)
 	gtk_widget_destroy (d);
 
 	stop_gdb ();
-	save_config ();
 	gtk_main_quit ();
 }
